@@ -34,6 +34,9 @@ class Qiniu(object):
         return qiniu.io
 
     def public_url(self, key, suffix=None):
+        if not key or key.startswith('http://'):
+            return key
+
         if not key:
             raise ValueError
         if suffix:
@@ -43,8 +46,9 @@ class Qiniu(object):
         return urljoin(base_url, key)
 
     def private_url(self, key, suffix=None):
-        if not key:
-            raise ValueError
+        if not key or key.startswith('http://'):
+            return key
+
         if suffix:
             key += suffix
 
